# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`rhsm`](#rhsm): Subscribe the node to RHSM

### Resource types

* [`rh_repo`](#rh_repo): Manage Red Hat subscriptions
* [`rh_subscription`](#rh_subscription): Manage Red Hat subscriptions

## Classes

### <a name="rhsm"></a>`rhsm`

rhsm

Subscribe the node to RHSM

Copyright 2014 Ger Apeldoorn, unless otherwise noted.

#### Examples

##### 

```puppet
include rhsm
```

##### 

```puppet
# Hierafile:
---
rhsm::rh_user: myuser
rhsm::rh_password: mypassword
```

#### Parameters

The following parameters are available in the `rhsm` class:

* [`rh_user`](#-rhsm--rh_user)
* [`rh_password`](#-rhsm--rh_password)
* [`org`](#-rhsm--org)
* [`activationkey`](#-rhsm--activationkey)
* [`servername`](#-rhsm--servername)
* [`serverprefix`](#-rhsm--serverprefix)
* [`serverport`](#-rhsm--serverport)
* [`ca_cert_dir`](#-rhsm--ca_cert_dir)
* [`repo_ca_cert_filename`](#-rhsm--repo_ca_cert_filename)
* [`repo_ca_cert_source`](#-rhsm--repo_ca_cert_source)
* [`manage_repos`](#-rhsm--manage_repos)
* [`full_refresh_on_yum`](#-rhsm--full_refresh_on_yum)
* [`proxy_hostname`](#-rhsm--proxy_hostname)
* [`proxy_scheme`](#-rhsm--proxy_scheme)
* [`proxy_port`](#-rhsm--proxy_port)
* [`proxy_user`](#-rhsm--proxy_user)
* [`proxy_password`](#-rhsm--proxy_password)
* [`no_proxy`](#-rhsm--no_proxy)
* [`baseurl`](#-rhsm--baseurl)
* [`package_ensure`](#-rhsm--package_ensure)
* [`enabled_subscription_ids`](#-rhsm--enabled_subscription_ids)
* [`enabled_repo_ids`](#-rhsm--enabled_repo_ids)
* [`server_timeout`](#-rhsm--server_timeout)
* [`inotify`](#-rhsm--inotify)
* [`process_timeout`](#-rhsm--process_timeout)
* [`manage_repo_filename`](#-rhsm--manage_repo_filename)
* [`repo_filename`](#-rhsm--repo_filename)
* [`plugin_settings`](#-rhsm--plugin_settings)
* [`package_profile_on_trans`](#-rhsm--package_profile_on_trans)

##### <a name="-rhsm--rh_user"></a>`rh_user`

Data type: `Optional[String[1]]`

User for the Customer Portal.
You need to specify either (rh_user and rh_password) or (org and activationkey)

Default value: `undef`

##### <a name="-rhsm--rh_password"></a>`rh_password`

Data type: `Optional[String[1]]`

Password for the rh_user account

Default value: `undef`

##### <a name="-rhsm--org"></a>`org`

Data type: `Optional[String[1]]`

Organization to use

Default value: `undef`

##### <a name="-rhsm--activationkey"></a>`activationkey`

Data type: `Optional[String[1]]`

Activationkey to use

Default value: `undef`

##### <a name="-rhsm--servername"></a>`servername`

Data type: `Stdlib::Fqdn`

Servername, default provided
Used directly in rhsm.conf template

Default value: `'subscription.rhsm.redhat.com'`

##### <a name="-rhsm--serverprefix"></a>`serverprefix`

Data type: `Stdlib::Absolutepath`

server.prefix to use
Used directly in rhsm.conf template
/rhsm for Satellite 6
/subscription for RHSM

Default value: `'/subscription'`

##### <a name="-rhsm--serverport"></a>`serverport`

Data type: `Stdlib::Port`

server.port to use
Used directly in rhsm.conf template

Default value: `443`

##### <a name="-rhsm--ca_cert_dir"></a>`ca_cert_dir`

Data type: `Stdlib::Absolutepath`

Server CA certificate location

Default value: `'/etc/rhsm/ca/'`

##### <a name="-rhsm--repo_ca_cert_filename"></a>`repo_ca_cert_filename`

Data type: `String[1]`

File containting the CA cert to use when generating yum repo configs
katello-server-ca.pem for Satellite 6
redhat-uep.pem for RHSM

Default value: `'redhat-uep.pem'`

##### <a name="-rhsm--repo_ca_cert_source"></a>`repo_ca_cert_source`

Data type: `Optional[String[1]]`

URI, if set the content is used for CA file resource ${ca_cert_dir}/${repo_ca_cert_filename}
Possible values are puppet:, file: and http:

Default value: `undef`

##### <a name="-rhsm--manage_repos"></a>`manage_repos`

Data type: `Integer[0,1]`

1 if subscription manager should manage yum repos file or
0 if the subscription is only used for tracking purposes

Default value: `1`

##### <a name="-rhsm--full_refresh_on_yum"></a>`full_refresh_on_yum`

Data type: `Integer[0,1]`

rhsm.full_refresh_on_yum
Used directly in rhsm.conf template
1 for Satellite 6
0 for RHSM

Default value: `0`

##### <a name="-rhsm--proxy_hostname"></a>`proxy_hostname`

Data type: `Optional[Stdlib::Fqdn]`

Proxy hostname

Default value: `undef`

##### <a name="-rhsm--proxy_scheme"></a>`proxy_scheme`

Data type: `Enum['http', 'https']`

Proxy scheme

Default value: `'http'`

##### <a name="-rhsm--proxy_port"></a>`proxy_port`

Data type: `Optional[Stdlib::Port]`

Proxy port

Default value: `undef`

##### <a name="-rhsm--proxy_user"></a>`proxy_user`

Data type: `Optional[String[1]]`

Proxy user

Default value: `undef`

##### <a name="-rhsm--proxy_password"></a>`proxy_password`

Data type: `Optional[String[1]]`

Proxy password

Default value: `undef`

##### <a name="-rhsm--no_proxy"></a>`no_proxy`

Data type: `Optional[String[1]]`

no_proxy definition

Default value: `undef`

##### <a name="-rhsm--baseurl"></a>`baseurl`

Data type: `Stdlib::Httpurl`

Base URL for rhsm, default provided

Default value: `'https://cdn.redhat.com'`

##### <a name="-rhsm--package_ensure"></a>`package_ensure`

Data type: `String[1]`

Whether to install subscription-manager, directly passed to the `ensure` param of the package.

Default value: `'installed'`

##### <a name="-rhsm--enabled_subscription_ids"></a>`enabled_subscription_ids`

Data type: `Array[String[1]]`

A listing of subscription IDs to provide to the subscription-manager attach --pool command.

Default value: `[]`

##### <a name="-rhsm--enabled_repo_ids"></a>`enabled_repo_ids`

Data type: `Array[String[1]]`

A listing of the Repo IDs to provide to the subscription-manager repo --enable command.

Default value: `[]`

##### <a name="-rhsm--server_timeout"></a>`server_timeout`

Data type: `Integer[0]`

HTTP timeout in seconds

Default value: `180`

##### <a name="-rhsm--inotify"></a>`inotify`

Data type: `Integer[0,1]`

Inotify is used for monitoring changes in directories with certificates. When this directory is mounted using a network
file system without inotify notification support (e.g. NFS), then disabling inotify is strongly recommended.

Default value: `1`

##### <a name="-rhsm--process_timeout"></a>`process_timeout`

Data type: `Integer[0]`

The time in seconds we will allow the rhsmd cron job to run before terminating the process.

Default value: `300`

##### <a name="-rhsm--manage_repo_filename"></a>`manage_repo_filename`

Data type: `Boolean`

Should puppet try to manage the repo file subscription-manager uses?

Default value: `true`

##### <a name="-rhsm--repo_filename"></a>`repo_filename`

Data type: `Stdlib::Absolutepath`

The name of the repo file subscription-manager uses.

Default value: `'/etc/yum.repos.d/redhat.repo'`

##### <a name="-rhsm--plugin_settings"></a>`plugin_settings`

Data type: `Hash`

Hash of {section => {key => value } } for the yum/dnf plugin.

Default value: `{ 'main' => { 'enabled' => 1 } }`

##### <a name="-rhsm--package_profile_on_trans"></a>`package_profile_on_trans`

Data type: `Integer[0,1]`

Run the package profile on each yum/dnf transaction

Default value: `0`

## Resource types

### <a name="rh_repo"></a>`rh_repo`

Manage Red Hat subscriptions

#### Properties

The following properties are available in the `rh_repo` type.

##### `ensure`

Valid values: `present`, `enabled`, `absent`, `disabled`

Aliases: `"enabled"=>"present", "disabled"=>"absent"`

The basic property that the resource should be in.

#### Parameters

The following parameters are available in the `rh_repo` type.

* [`name`](#-rh_repo--name)
* [`provider`](#-rh_repo--provider)

##### <a name="-rh_repo--name"></a>`name`

namevar


##### <a name="-rh_repo--provider"></a>`provider`

The specific backend to use for this `rh_repo` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="rh_subscription"></a>`rh_subscription`

Manage Red Hat subscriptions

#### Properties

The following properties are available in the `rh_subscription` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `rh_subscription` type.

* [`name`](#-rh_subscription--name)
* [`provider`](#-rh_subscription--provider)
* [`serial`](#-rh_subscription--serial)

##### <a name="-rh_subscription--name"></a>`name`

namevar


##### <a name="-rh_subscription--provider"></a>`provider`

The specific backend to use for this `rh_subscription` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-rh_subscription--serial"></a>`serial`


